References
==========

.. [Kim_2019] Kim, Jinsung, et al. "A code generator for high-performance \
    tensor contractions on GPUs." 2019 IEEE/ACM International Symposium on Code \
    Generation and Optimization (CGO). IEEE, 2019. \
    `(DOI) <https://doi.org/10.1109/CGO.2019.8661182>`__

.. [OpenCL_2011] Munshi, Aaftab, et al. OpenCL programming guide. Pearson Education, 2011. \
    `(DOI) <https://dl.acm.org/doi/10.5555/2049883>`__

..
  .. [Daniel_2018] Daniel, G., and Johnnie Gray. "opt_einsum-a python package for \
      optimizing contraction order for einsum-like expressions." Journal of Open \
      Source Software 3.26 (2018). \
      `(DOI) <https://doi.org/10.21105/joss.00753>`__
